@@ -16,8 +16,7 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef FR_PROCESS_H
@@ -97,7 +96,7 @@ void        fr_process_add_arg              (FrProcess    *fr_proc,
 					     const char   *arg);
 void        fr_process_add_arg_concat       (FrProcess    *fr_proc,
 					     const char   *arg,
-					     ...);
+					     ...) G_GNUC_NULL_TERMINATED;
 void        fr_process_add_arg_printf       (FrProcess    *fr_proc,
 					     const char   *format,
 					     ...) G_GNUC_PRINTF (2, 3);
